# Itch.io Free Games

Warning: Site Update Paused
This site uses GitHub actions to collect data, and uses GitHub Pages to host the site.
On 13 Feb, 2025, the repository's GitHub Actions cache and artifacts have been wiped.
I didn't receive any notification about this, so I don't know if this was just a GitHub bot randomly deleting stuff, or if this was requested by either Itch.io, or one of the developers whose games are listed here.
Regardless, I don't want to risk my GitHub account getting banned, so I'm pausing the site update for now.
I might look into hosting the site somewhere else, but there's no ETA for that.

## Active sales

Name | Sale end (UTC) |  |  |  |
--- | --- | --- | --- | --- | ---
$active_sales_rows

## Upcoming sales

Name | Sale start (UTC) |  |  |  |
--- | --- | --- | --- | --- | ---
$upcoming_sales_rows

## Last update

$last_update (UTC)

Last checked sale: $last_sale

## Legend

🌐: Game URL on itch.io

📜: Details about the game in JSON format

✔: Claimable game

❌: Download only game

🕑: Claimability unknown

🥇: First time on sale

## Source Code

https://github.com/Smart123s/ItchClaim

## Data in JSON format

📑 Active sales

📑 Upcoming sales

📑 Every sale

## Legal

Copyright (c) 2022-2024 Péter Tombor.
Released under The MIT License (MIT)
Please read the full license.

Game and sales data are collected from itch.io.
The data shown on this site may be inaccurate.
Please read the license for legal disclaimers.
This site is not affiliated with Itch Corp.